@@ -7,7 +7,7 @@ import gtk
 import requests
 import webbrowser
 import json
-
+import argparse
 from os.path import expanduser
 
 try:
@@ -15,6 +15,13 @@ try:
 except ImportError:
     import appindicator_replacement as appindicator
 
+##This is to get --version to work
+try:
+	import pkg_resources
+	__version = pkg_resources.require("hackertray")[0].version
+except ImportError, e:
+	__version = "Can't read version number."
+
 from hackernews import HackerNews
 
 class HackerNewsApp:
@@ -72,8 +79,8 @@ class HackerNewsApp:
 		l=list(self.db)
 		home = expanduser("~")
 		#truncate the file
-		file = open(home+'/.hackertray.json', 'w+')
-		file.write(json.dumps(l))
+		with open(home+'/.hackertray.json', 'w+') as file:
+			file.write(json.dumps(l))
 		gtk.main_quit()
 
 	def run(self):
@@ -118,5 +125,8 @@ class HackerNewsApp:
 			gtk.timeout_add(10*60*1000, self.refresh)
 
 def main():
+	parser = argparse.ArgumentParser(description='Hacker News in your System Tray')
+	parser.add_argument('--version', action='version', version=__version)
+	parser.parse_args()
 	indicator = HackerNewsApp()
 	indicator.run()
